/***************************************************************************
 *                                                                         *
 *   kemboss - Graphical user interface for EMBOSS                         *
 *                                                                         *
 *   Copyright (C) 2007-2020 Tobias Schwarz (mail@tobias-schwarz.net)      *
 *                                                                         *
 *   Based on the EMBOSS.kaptn scripts by Thomas Siegmund                  *
 *                                                                         *
 *   This program is free software; you can redistribute and/or modify     *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version, and provided that the above       *
 *   copyright and permission notice is included with all distributed      *
 *   copies of this or derived software.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 **************************************************************************/

#ifndef DBDLG_H
#define DBDLG_H

#include "settings.h"
#include "kemboss.h"
#include "runEmbossApp.h"
#include "ui_dbDlg.h"

class dbDlg : public QMainWindow, private Ui::DbDialog
{
    Q_OBJECT

public:
    dbDlg(kemboss *parent = nullptr, kembossSettings *fksettings = nullptr);

private slots:
    void done();
    void helpRequested();
    void getAvailableDatabases();
    void getAvailableServer();
    void dbtell();
    void servertell();
    void showserver();
    void showdb();
    void on_REBASEGroupBox_clicked() { database = "rebase"; extractDbChanged(); }
    void on_CUTGGroupBox_clicked() { database = "cutg"; extractDbChanged(); }
    void on_AAINDEXGroupBox_clicked() { database = "aaindex"; extractDbChanged(); }
    void on_JASPARGroupBox_clicked() { database = "jasp"; extractDbChanged(); }
    void on_PRINTSGroupBox_clicked() { database = "prints"; extractDbChanged(); }
    void on_PROSITEGroupBox_clicked() { database = "pros"; extractDbChanged(); }
    void on_TRANSFACGroupBox_clicked() { database = "tf"; extractDbChanged(); }
    void on_DirectoryPushButton_clicked() { setExistingDir(tr("Select sequence database directory"), DirectoryLineEdit); }
    void on_IndexDirPushButton_clicked() { setExistingDir(tr("Select database index directory"), IndexDirLineEdit); }
    void on_AddDBPushButton_clicked();
    void on_WithrefmFilePushButton_clicked() { setOpenFile(tr("Select REBASE withrefm file"), WithrefmFileLineEdit); }
    void on_ProtoFilePushButton_clicked() { setOpenFile(tr("Select REBASE proto file"), ProtoFileLineEdit); }
    void on_CUTGDirectoryPushButton_clicked() { setExistingDir(tr("Select CUTG data directory"), CUTGDirectoryLineEdit); }
    void on_GeneralLogOutputFilePushButton_clicked() { setSaveFile(tr("Select general log output file"), AAINDEXFileLineEdit); }
    void on_AAINDEXFilePushButton_clicked() { setOpenFile(tr("Select AAINDEX database file"), TRANSFACFileLineEdit); }
    void on_PROSITEDirectoryPushButton_clicked() { setExistingDir(tr("Select PROSITE data directory"), PROSITEDirectoryLineEdit); }
    void on_JASPARDirectoryPushButton_clicked() { setExistingDir(tr("Select JASPAR data directory"), JASPARDirectoryLineEdit); }
    void on_TRANSFACFilePushButton_clicked() { setOpenFile(tr("Select 'site.dat' TRANSFAC file"), AAINDEXFileLineEdit); }
    void on_PRINTSFilePushButton_clicked() { setOpenFile(tr("Select PRINTS database file"), PRINTSFileLineEdit); }
    void on_OpenHomepagePushButton_clicked();
    void on_ExtractDatabasePushButton_clicked();
    void on_DatabaseDirectoryPushButton_clicked() { setExistingDir(tr("Select database directory"), DatabaseDirectoryLineEdit); }
    void on_LogOutputFilePushButton_clicked() { setSaveFile(tr("Select general log output file"), LogOutputFileLineEdit); }
    void on_IndexDirectoryPushButton_clicked() { setExistingDir(tr("Select index directory"), IndexDirectoryLineEdit); }
    void on_IndexDatabasePushButton_clicked();
    void on_DatabaseTypeComboBox_currentIndexChanged(const QString &text);
    void on_MethodComboBox_currentIndexChanged(const QString &text);
    void on_ProgramComboBox_currentIndexChanged(int index);
    void on_CachefilePushButton_clicked() { setSaveFile(tr("Select server cache output file"), CachefileLineEdit); }
    void on_OutfilePushButton_clicked() { setSaveFile(tr("Select output file"), OutfileLineEdit); }
    void on_GenerateCachefilePushButton_clicked();
    void on_DatabasePushButton_clicked();
    void on_ServerPushButton_clicked();
    void on_MainTab_currentChanged(int index);

private:
    void closeEvent(QCloseEvent *event);
    QString database;
    void readSettings();
    void writeSettings();
    void extractDbChanged();
    void setExistingDir(const QString &dlgMsg, QLineEdit *lineEdit);
    void setOpenFile(const QString &dlgMsg, QLineEdit *lineEdit);
    void setSaveFile(const QString &dlgMsg, QLineEdit *lineEdit);
    kemboss *mainKembossWindow;
    kembossSettings *ksettings;
    krunEmbossApp *runEmbossApp;  // embossApp for Generate cachefile, Index database and Extract database
    krunEmbossApp *dbtellApp;
    krunEmbossApp *servertellApp;
    krunEmbossApp *showdbApp;
    krunEmbossApp *showserverApp;
};

#endif
