/***************************************************************************
 *                                                                         *
 *   kemboss - Graphical user interface for EMBOSS                         *
 *                                                                         *
 *   Copyright (C) 2007-2020 Tobias Schwarz (mail@tobias-schwarz.net)      *
 *                                                                         *
 *   Based on the EMBOSS.kaptn scripts by Thomas Siegmund                  *
 *                                                                         *
 *   This program is free software; you can redistribute and/or modify     *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version, and provided that the above       *
 *   copyright and permission notice is included with all distributed      *
 *   copies of this or derived software.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 **************************************************************************/

#ifndef KEMBOSS_H
#define KEMBOSS_H

#include <QPointer>

#include "programWindowClass.h"
#include "settings.h"
#include "ui_kemboss.h"

class kemboss : public kembossWindow, private Ui::kemboss
{
   Q_OBJECT

public:
   kemboss(QMainWindow *parent = nullptr, bool portable = false);
   // Constructor
   QList<QPointer<kprogramWindow> > programWindows;
   // List of all open EMBOSS program windows
   kembossSettings ksettings;
   // kemboss settings
   void loadLists(const bool phylipnew);
   void checkServer();

protected:
   void closeEvent(QCloseEvent *event);

private slots:
   void on_actionCloseAll_triggered();
   void on_actionPreferences_triggered();
   void on_actionDatabase_triggered();
   void on_RunProgramPushButton_clicked();
   //void on_BatchProcessingPushButton_clicked();
   void on_actionEmbossHelp_triggered();
   void on_SearchByKeywordPushButton_clicked();
   void wossname();
   void serverResponse(const int exitCode);

private:
   bool loadSettings(const QString &fileName);
   bool saveSettings(const QString &fileName);
   bool maybeSave();
   void setCurrentFile(const QString &fileName);
   void createProgramTree(const QString &programsFile);
   void createProgramList(const QString &programsFile);
   kprogramWindow* createProgramWindow(const QString &newProgram);
   QPointer<krunEmbossApp> runEmbossApp;
   QString selectedProgram();
};

#endif
