/***************************************************************************
 *                                                                         *
 *   kemboss - Graphical user interface for EMBOSS                         *
 *                                                                         *
 *   Copyright (C) 2007-2014 Tobias Schwarz (mail@tobias-schwarz.net)      *
 *                                                                         *
 *   Based on the EMBOSS.kaptn scripts by Thomas Siegmund                  *
 *                                                                         *
 *   This program is free software; you can redistribute and/or modify     *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version, and provided that the above       *
 *   copyright and permission notice is included with all distributed      *
 *   copies of this or derived software.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 **************************************************************************/

#include "ksshared.h"

#include <QCoreApplication>
#include <QDir>
#include <QFile>
#include <QCryptographicHash>
#include <QMutex>
#include <QMutexLocker>
#include <QTextStream>
#include <QDateTime>

QByteArray kembossServer::SHA256hash(const QByteArray &pw)
{
    return QCryptographicHash::hash(pw, QCryptographicHash::Sha256);
}

QString kembossServer::getServerConfigFile()
{
    QString file = "";

    // Search for an existing server configuration file
    if (QFile::exists("/etc/kembossd/server.config")) file = "/etc/kembossd/server.config";
    else if (QFile::exists("/sw/etc/kembossd/server.config")) file = "/sw/etc/kembossd/server.config";
    else if (QFile::exists("/Applications/kembossd.app/Contents/Resources/server.config")) file = "/Applications/kembossd.app/Contents/Resources/server.config";
    else if (QFile::exists(QCoreApplication::applicationDirPath()+"/server.config")) file = QCoreApplication::applicationDirPath()+"/server.config";
    else if (QFile::exists(QDir::homePath()+"/kembossd/server.config")) file = QDir::homePath()+"/kembossd/server.config";

    // If we did not find an existing server configuration file we create one. The location of the file depends on the OS.
    if (file.isEmpty()) {
        QDir dir;
        #ifdef Q_OS_WIN32
            file = QCoreApplication::applicationDirPath()+"/server.config";
        #else
          #ifdef Q_OS_MAC
            if (dir.exists("/Applications/kembossd.app/Contents"))
                file = "/Applications/kembossd.app/Contents/Resources/server.config";
            else file = QCoreApplication::applicationDirPath()+"/server.config";
          #else
            if (dir.exists("/etc"))
                file = "/etc/kembossd/server.config";
            else file = QCoreApplication::applicationDirPath()+"/server.config";
          #endif
        #endif
    }

    return file;
}

void kembossServer::msgStdOut(const QString &msg, const QString &logfile)
{
    QMutex mutex;
    QMutexLocker locker(&mutex);

    if (logfile == "stdout") {
        QTextStream qstdout(stdout);
        qstdout << msg << endl;
    } else {
        QFile file(logfile);
        if (!file.open(QIODevice::WriteOnly | QIODevice::Append | QIODevice::Text)) {
            QTextStream qstdout(stdout);
            qstdout << "Couldn't open logfile " + logfile << endl;
            return;
        }
        QTextStream qfout(&file);
        QString datetime = QDateTime::currentDateTime().toString("dd-MM-yyyy hh-mm-ss");
        qfout << datetime + " " + msg << "\n";
        file.close();
    }
}

void kembossServer::msgStdErr(const QString &msg, const QString &logfile)
{
    QMutex mutex;
    QMutexLocker locker(&mutex);

    QString datetime = QDateTime::currentDateTime().toString("dd-MM-yyyy hh-mm-ss");

    if (logfile == "stdout") {
        #ifdef Q_OS_WIN32
            QTextStream qstderr(stdout);
            // On a Windows console stderr doesn't exist
        #else
            QTextStream qstderr(stderr);
        #endif
        qstderr << datetime + " " + msg << endl;
    } else {
        QFile file(logfile+".error");
        if (!file.open(QIODevice::WriteOnly | QIODevice::Append | QIODevice::Text)) {
            QTextStream qstdout(stdout);
            qstdout << "Couldn't open logfile " + logfile+".error" << endl;
            return;
        }
        QTextStream qfout(&file);
        qfout << datetime + " " + msg << "\n";
        file.close();
    }
}
