/***************************************************************************
 *                                                                         *
 *   kemboss - Graphical user interface for EMBOSS                         *
 *                                                                         *
 *   Copyright (C) 2007-2019 Tobias Schwarz (mail@tobias-schwarz.net)      *
 *                                                                         *
 *   Based on the EMBOSS.kaptn scripts by Thomas Siegmund                  *
 *                                                                         *
 *   This program is free software; you can redistribute and/or modify     *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version, and provided that the above       *
 *   copyright and permission notice is included with all distributed      *
 *   copies of this or derived software.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 **************************************************************************/

#ifndef SQL_H
#define SQL_H

#include <QString>
#include <QVariant>
#include <QList>
#include <QtSql/QSqlDatabase>
#include <QtSql/QSqlQueryModel>

namespace ksql
{
enum dbType { unknown = 0,
              MySQL = 1,
              SQLite = 2,
              PostgreSQL = 3,
              ODBC = 4,
              DB2 = 5,
              IBASE = 6,
              OCI = 7
            };
QString dbTypeStr(const dbType type);

dbType checkDbDriver();
// Check if the database driver selected is available on the system. Returns the name of the db driver on an empty string if the driver is not available
bool connectToDb(QSqlDatabase *db, const dbType type);
// Creates a connection to the SQL database. The database name, ip, port and password are taken from the configFile
bool checkDb();
// Check if the database tables are present and are suitable for the kemboss server version
bool createDbTables(const dbType type);
// Creates the database tables, required by the kembossd
bool updateDbTables(const uint dbVersion);
// If the kembossd version is newer than the tables in the SQL database, the db tables are updated
QVariant execSqlQuery(const QString sqlQuery, const QString errorMsg, const bool returnResult = false);
// Executes the SQL statement 'query'. If an error occurs, errorMsg is shown and the function returns 0.
// If returnResult is true, the first result of the SQL statement is returned is returned as a QVariant.
quint32 newUser(const QString name, const QString group, const QByteArray pwHash, const bool newPw, const QString email);
// Stores the user information in the SQL database and returns the unique user id

}

#endif // SQL_H
