/***************************************************************************
 *                                                                         *
 *   kemboss - Graphical user interface for EMBOSS                         *
 *                                                                         *
 *   Copyright (C) 2007-2019 Tobias Schwarz (mail@tobias-schwarz.net)      *
 *                                                                         *
 *   Based on the EMBOSS.kaptn scripts by Thomas Siegmund                  *
 *                                                                         *
 *   This program is free software; you can redistribute and/or modify     *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version, and provided that the above       *
 *   copyright and permission notice is included with all distributed      *
 *   copies of this or derived software.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 **************************************************************************/

#include "loadFileThread.h"

#include <QFile>
#include <QTextStream>
#include <QDebug>

loadFileThread::loadFileThread(QObject *parent, const QString &fileName, QTextEdit *textEdit) : QThread(parent)
{
    filename = fileName;
    pTextEdit = textEdit;
    abort = false;
}

void loadFileThread::run()
{
   if (pTextEdit == nullptr) {
      qCritical() << "Empty pointer in loadFileThread";
      return;
   }
   QFile file(filename);

   QString text;
   if (!file.open(QFile::ReadOnly | QFile::Text)) {
      text = tr("Cannot open input file %1:\n%2.").arg(filename).arg(file.errorString());
      emit fileRead(pTextEdit, text);
      emit finishedLoading(pTextEdit);
      return;
   }
   QTextStream in(&file);
   while (!in.atEnd()) {
      if (abort) return;
      text = in.read(10000);
      emit fileRead(pTextEdit, text);
   }
   emit finishedLoading(pTextEdit);
}
