/***************************************************************************
 *                                                                         *
 *   kemboss - Graphical user interface for EMBOSS                         *
 *                                                                         *
 *   Copyright (C) 2007-2013 Tobias Schwarz (mail@tobias-schwarz.net)      *
 *                                                                         *
 *   Based on the EMBOSS.kaptn scripts by Thomas Siegmund                  *
 *                                                                         *
 *   This program is free software; you can redistribute and/or modify     *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version, and provided that the above       *
 *   copyright and permission notice is included with all distributed      *
 *   copies of this or derived software.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 **************************************************************************/

#ifndef EMBASSYPROGRAMWINDOWS_H
#define EMBASSYPROGRAMWINDOWS_H

#include "programWindowClass.h"
#include "associated_qualifiers.h"

#include "ui_kfclique.h"
#include "ui_kfconsense.h"
#include "ui_kfcontml.h"
#include "ui_kfcontrast.h"
#include "ui_kfdnacomp.h"
#include "ui_kfdnadist.h"
#include "ui_kfdnainvar.h"
#include "ui_kfdnaml.h"
#include "ui_kffactor.h"
#include "ui_kfpars.h"
#include "ui_kfpenny.h"
#include "ui_kfdollop.h"
#include "ui_kfmatrix.h"
#include "ui_kfgendist.h"
#include "ui_kfprotdist.h"
#include "ui_kfrestml.h"
#include "ui_kfbootstrap.h"
#include "ui_kfdiscboot.h"
#include "ui_kfrestdist.h"
#include "ui_kftreedist.h"
#include "ui_kfdraw.h"

class kfbootstrap : public kprogramWindow, private Ui::kfbootstrap
{
    Q_OBJECT
public:
    kfbootstrap(kembossWindow *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
   void on_InputCategoriesFilePushButton_clicked() { selectOpenFile(tr("Open input categories file") ,InputCategoriesFileLineEdit); }
   void on_WeightsFilePushButton_clicked() { selectOpenFile(tr("Open weights file") ,WeightsFileLineEdit); }
   void on_MixturesFilePushButton_clicked() { selectOpenFile(tr("Open mixtures file") ,MixturesFileLineEdit); }
   void on_AncestorsFilePushButton_clicked() { selectOpenFile(tr("Open ancestors file") ,AncestorsFileLineEdit); }
   void on_FactorsFilePushButton_clicked() { selectOpenFile(tr("Open factors file") ,FactorsFileLineEdit); }
   void on_ProgramComboBox_currentIndexChanged(const QString &text);

private:
   void beforeRunningProgram();
};

class kfclique : public kprogramWindow, private Ui::kfclique
{
    Q_OBJECT
public:
    kfclique(kembossWindow *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save tree output as", OutputFileLineEdit2); }
   void on_AncestralStatesFilePushButton_clicked() { selectOpenFile(tr("Open ancestral states file") ,AncestralStatesFileLineEdit); }
   void on_MultistateFactorsFilePushButton_clicked() { selectOpenFile(tr("Open multistate factors file") ,MultistateFactorsFileLineEdit); }
   void on_WeightsFilePushButton_clicked() { selectOpenFile(tr("Open weights file") ,WeightsFileLineEdit); }

private:
   void beforeRunningProgram();
};

class kfconsense : public kprogramWindow, private Ui::kfconsense
{
    Q_OBJECT
public:
    kfconsense(kembossWindow *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save tree output as", OutputFileLineEdit2); }

private:
   void beforeRunningProgram();
};

class kfcontml : public kprogramWindow, private Ui::kfcontml
{
    Q_OBJECT
public:
    kfcontml(kembossWindow *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save tree output as", OutputFileLineEdit2); }

private:
   void beforeRunningProgram();
};

class kfcontrast : public kprogramWindow, private Ui::kfcontrast
{
    Q_OBJECT
public:
    kfcontrast(kembossWindow *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
   void beforeRunningProgram();
};

class kfdiscboot : public kprogramWindow, private Ui::kfdiscboot
{
    Q_OBJECT
public:
    kfdiscboot(kembossWindow *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_SaveAncestorOutputFileAsPushButton_clicked() { selectSaveFile("Save ancestor data output as", AncestorOutputFileLineEdit); }
   void on_SaveMixOutputFileAsPushButton_clicked() { selectSaveFile("Save mixture data output as", MixOutputFileLineEdit); }
   void on_SaveFactorOutputFileAsPushButton_clicked() { selectSaveFile("Save factor data output as", FactorOutputFileLineEdit); }
   void on_WeightsFilePushButton_clicked() { selectOpenFile(tr("Open weights file") ,WeightsFileLineEdit); }
   void on_AncestorsFilePushButton_clicked() { selectOpenFile(tr("Open ancestors file") ,AncestorsFileLineEdit); }
   void on_MixturesFilePushButton_clicked() { selectOpenFile(tr("Open mixtures file") ,MixturesFileLineEdit); }
   void on_FactorsFilePushButton_clicked() { selectOpenFile(tr("Open factors file") ,FactorsFileLineEdit); }

private:
   void beforeRunningProgram();
};

class kfdnadist : public kprogramWindow, private Ui::kfdnadist
{
    Q_OBJECT
public:
    kfdnadist(kembossWindow *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    void beforeRunningProgram();

private slots:
   void on_SubstitutionRateCategoriesFilePushButton_clicked() { selectOpenFile(tr("Open substitution rate categories file") ,SubstitutionRateCategoriesFileLineEdit); }
   void on_WeightsFilePushButton_clicked() { selectOpenFile(tr("Open weights file") ,WeightsFileLineEdit); }
};

class kfdnacomp : public kprogramWindow, private Ui::kfdnacomp
{
    Q_OBJECT
public:
    kfdnacomp(kembossWindow *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_SaveInputFileAsPushButton3_clicked() { selectAndSaveFile("Save weights file as", InputFileLineEdit3, InputTextEdit3); }
   void on_OpenInputFilePushButton3_clicked() { selectAndOpenFile("Open weights file", InputFileLineEdit3, InputTextEdit3); }
   void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save tree output as", OutputFileLineEdit2); }

private:
   void beforeRunningProgram();
};

class kfdnainvar : public kprogramWindow, private Ui::kfdnainvar
{
    Q_OBJECT
public:
    kfdnainvar(kembossWindow *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
   void beforeRunningProgram();
};

class kfdnaml : public kprogramWindow, private Ui::kfdnaml
{
    Q_OBJECT
public:
    kfdnaml(kembossWindow *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
   void on_SubstitutionRateCategoriesFilePushButton_clicked() { selectOpenFile(tr("Open substitution rate categories file") ,SubstitutionRateCategoriesFileLineEdit); }
   void on_WeightsFilePushButton_clicked() { selectOpenFile(tr("Open weights file") ,WeightsFileLineEdit); }
   void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save tree output as", OutputFileLineEdit2); }
   void on_ProgramComboBox_currentIndexChanged(const QString &text);

private:
   void beforeRunningProgram();
};

class kfdollop : public kprogramWindow, private Ui::kfdollop
{
    Q_OBJECT
public:
    kfdollop(kembossWindow *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
   void on_AncestralStatesFilePushButton_clicked() { selectOpenFile(tr("Open ancestral states file") ,AncestralStatesFileLineEdit); }
   void on_WeightsFilePushButton_clicked() { selectOpenFile(tr("Open weights file") ,WeightsFileLineEdit); }
   void on_MixtureFilePushButton_clicked() { selectOpenFile(tr("Open mixture file") ,MixtureFileLineEdit); }
   void on_ProgramComboBox_currentIndexChanged(const QString &text);

private:
   void beforeRunningProgram();
};

class kfgendist : public kprogramWindow, private Ui::kfgendist
{
    Q_OBJECT
public:
    kfgendist(kembossWindow *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    void beforeRunningProgram();
};

class kfmatrix : public kprogramWindow, private Ui::kfmatrix
{
    Q_OBJECT
public:
    kfmatrix(kembossWindow *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
   void on_ProgramComboBox_currentIndexChanged(const QString &text);

private:
   void beforeRunningProgram();
};

class kfpars : public kprogramWindow, private Ui::kfpars
{
    Q_OBJECT
public:
    kfpars(kembossWindow *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
   void on_ProgramComboBox_currentIndexChanged(const QString &text);

private:
   void beforeRunningProgram();
};

class kfpenny : public kprogramWindow, private Ui::kfpenny
{
    Q_OBJECT
public:
    kfpenny(kembossWindow *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
   void on_AncestralStatesFilePushButton_clicked() { selectOpenFile(tr("Open ancestral states file") ,AncestralStatesFileLineEdit); }
   void on_WeightsFilePushButton_clicked() { selectOpenFile(tr("Open weights file") ,WeightsFileLineEdit); }
   void on_MixtureFilePushButton_clicked() { selectOpenFile(tr("Open mixture file") ,MixtureFileLineEdit); }
   void on_ProgramComboBox_currentIndexChanged(const QString &text);

private:
   void beforeRunningProgram();
};

class kfprotdist : public kprogramWindow, private Ui::kfprotdist
{
    Q_OBJECT
public:
    kfprotdist(kembossWindow *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    void beforeRunningProgram();

private slots:
   void on_SubstitutionRateCategoriesFilePushButton_clicked() { selectOpenFile(tr("Open substitution rate categories file") ,SubstitutionRateCategoriesFileLineEdit); }
   void on_WeightsFilePushButton_clicked() { selectOpenFile(tr("Open weights file") ,WeightsFileLineEdit); }
};

class kfrestml : public kprogramWindow, private Ui::kfrestml
{
    Q_OBJECT
public:
    kfrestml(kembossWindow *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_WeightsFilePushButton_clicked() { selectOpenFile(tr("Open weights file") ,WeightsFileLineEdit); }

private:
   void beforeRunningProgram();
};

class kfrestdist : public kprogramWindow, private Ui::kfrestdist
{
    Q_OBJECT
public:
    kfrestdist(kembossWindow *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class kftreedist : public kprogramWindow, private Ui::kftreedist
{
    Q_OBJECT
public:
    kftreedist(kembossWindow *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
   void on_ProgramComboBox_currentIndexChanged(const QString &text);

private:
   void beforeRunningProgram();
};

class kffactor : public kprogramWindow, private Ui::kffactor
{
    Q_OBJECT
public:
    kffactor(kembossWindow *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_SaveAncestorOutputFileAsPushButton_clicked() { selectSaveFile("Save ancestor data output as", AncestorOutputFileLineEdit); }
   void on_SaveFactorOutputFileAsPushButton_clicked() { selectSaveFile("Save factor data output as", FactorOutputFileLineEdit); }

private:
   void beforeRunningProgram();

};

class kfdraw : public kprogramWindow, private Ui::kfdraw
{
    Q_OBJECT
public:
    kfdraw(kembossWindow *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
   void on_ProgramComboBox_currentIndexChanged(const QString &text);

private:
   void beforeRunningProgram();

};

#endif
