/***************************************************************************
 *                                                                         *
 *   kemboss - Graphical user interface for EMBOSS                         *
 *                                                                         *
 *   Copyright (C) 2007-2019 Tobias Schwarz (mail@tobias-schwarz.net)      *
 *                                                                         *
 *   Based on the EMBOSS.kaptn scripts by Thomas Siegmund                  *
 *                                                                         *
 *   This program is free software; you can redistribute and/or modify     *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version, and provided that the above       *
 *   copyright and permission notice is included with all distributed      *
 *   copies of this or derived software.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 **************************************************************************/

#ifndef FINISHEDPROGRAMWINDOWS_H
#define FINISHEDPROGRAMWINDOWS_H

#include "programWindowClass.h"
#include "associated_qualifiers.h"
#include "kemboss.h"

#include "ui_kabiview.h"
#include "ui_kaligncopy.h"
#include "ui_kalignment.h"
#include "ui_kanalyzeseq.h"
#include "ui_kantigenic.h"
#include "ui_kassembly.h"
#include "ui_kbacktranseq.h"
#include "ui_kbacktranambig.h"
#include "ui_kbanana.h"
#include "ui_kbtwisted.h"
#include "ui_kchaos.h"
#include "ui_kcharge.h"
#include "ui_kchecktrans.h"
#include "ui_kcodcmp.h"
#include "ui_kcodcopy.h"
#include "ui_kcoderet.h"
#include "ui_kcompseq.h"
#include "ui_kcons.h"
#include "ui_kconsambig.h"
#include "ui_kcpgplot.h"
#include "ui_kcpgreport.h"
#include "ui_kdan.h"
#include "ui_kdensity.h"
#include "ui_kdiffseq.h"
#include "ui_kdigest.h"
#include "ui_kdistmat.h"
#include "ui_kdotplot.h"
#include "ui_kdrawmap.h"
#include "ui_kedialign.h"
#include "ui_keinverted.h"
#include "ui_kemma.h"
#include "ui_kemowse.h"
#include "ui_kepestfind.h"
#include "ui_keprimer3.h"
#include "ui_kequicktandem.h"
#include "ui_kest2genome.h"
#include "ui_ketandem.h"
#include "ui_kextractfeat.h"
#include "ui_kfeatcopy.h"
#include "ui_kfeatmerge.h"
#include "ui_kfeatreport.h"
#include "ui_kfindkm.h"
#include "ui_kfreak.h"
#include "ui_kgetorf.h"
#include "ui_khelixturnhelix.h"
#include "ui_khmoment.h"
#include "ui_kiep.h"
#include "ui_kinfoalign.h"
#include "ui_kinfoseq.h"
#include "ui_kinfo.h"
#include "ui_kisochore.h"
#include "ui_kjaspscan.h"
#include "ui_klistor.h"
#include "ui_kmakeseq.h"
#include "ui_kmaskfeat.h"
#include "ui_kmegamerger.h"
#include "ui_kmerger.h"
#include "ui_kmodifyseq.h"
#include "ui_kmsbar.h"
#include "ui_kmwfilter.h"
#include "ui_kmwcontam.h"
#include "ui_knewseq.h"
#include "ui_kno.h"
#include "ui_koctanol.h"
#include "ui_koddcomp.h"
#include "ui_kpalindrome.h"
#include "ui_kpatmatmotifs.h"
#include "ui_kpepcoil.h"
#include "ui_kpepdisplay.h"
#include "ui_kpepinfo.h"
#include "ui_kpepwindow.h"
#include "ui_kplotcon.h"
#include "ui_kplotorf.h"
#include "ui_kpolydot.h"
#include "ui_kprettyplot.h"
#include "ui_kprettyseq.h"
#include "ui_kprimersearch.h"
#include "ui_kprofit.h"
#include "ui_kprophecy.h"
#include "ui_kprophet.h"
#include "ui_kpsiphi.h"
#include "ui_kredata.h"
#include "ui_kremap.h"
#include "ui_kremutate.h"
#include "ui_krestrict.h"
#include "ui_krestover.h"
#include "ui_kseq.h"
#include "ui_kshowalign.h"
#include "ui_kshowfeat.h"
#include "ui_kshoworf.h"
#include "ui_kshowseq.h"
#include "ui_kshowpep.h"
#include "ui_ksigcleave.h"
#include "ui_ksirna.h"
#include "ui_ksixpack.h"
#include "ui_kskipredundant.h"
#include "ui_kstssearch.h"
#include "ui_ksyco.h"
#include "ui_ktcode.h"
#include "ui_ktextsearch.h"
#include "ui_ktfscan.h"
#include "ui_ktmap.h"
#include "ui_ktranalign.h"
#include "ui_ktranseq.h"
#include "ui_ktrimest.h"
#include "ui_ktrimseq.h"
#include "ui_ktwofeat.h"
#include "ui_kunion.h"
#include "ui_kvectorstrip.h"
#include "ui_kwhichdb.h"
#include "ui_kwobble.h"
#include "ui_kwordfinder.h"
#include "ui_kwordmatch.h"
#include "ui_kedam.h"
#include "ui_kfinddatabase.h"
#include "ui_konto.h"
#include "ui_ktax.h"
#include "ui_kgo.h"
#include "ui_kdr.h"
#include "ui_kget.h"
#include "ui_kseqxref.h"
#include "ui_kfeattext.h"

class kabiview : public kprogramWindow, private Ui::kabiview
{
    Q_OBJECT
public:
    kabiview(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save graph as", OutputFileLineEdit2); }

private:
    virtual void beforeRunningProgram();
};

class kaligncopy : public kprogramWindow, private Ui::kaligncopy
{
    Q_OBJECT
public:
   kaligncopy(kemboss *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
   void on_AlignmentAssociatedQualifiersPushButton2_clicked() { openAAQForm("2"); }
   void on_ProgramComboBox_currentIndexChanged(const QString &text) { runEmbossApp->setEmbossApp(text); }
};

class kalignment : public kprogramWindow, private Ui::kalignment
{
    Q_OBJECT
public:
   kalignment(kemboss *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
   void on_ErrorfileSaveAsPushButton_clicked() { selectSaveFile("Save error file as", ErrorfileLineEdit); }
   void on_SequenceAssociatedQualifiersPushButton2_clicked() { openSAQForm("2"); }
   void on_ProgramComboBox_currentIndexChanged(const QString &text);

private:
   virtual void beforeRunningProgram();
};

class kanalyzeseq : public kprogramWindow, private Ui::kanalyzeseq
{
   Q_OBJECT
public:
   kanalyzeseq(kemboss *parent = nullptr, const QString program = "") : kprogramWindow(parent) { setupUi(this); postWindowCreated(); setEmbossApp(program); }
   void setEmbossApp(const QString &appName);

private slots:
   void on_WordCountGroupBox_clicked() { setEmbossApp("wordcount"); }
   void on_SeqcountGroupBox_clicked() { setEmbossApp("seqcount"); }
   void on_SeqmatchallGroupBox_clicked() { setEmbossApp("seqmatchall"); }
   void on_RegularExpressionSearchGroupBox_clicked() { setEmbossApp("dreg"); }
   void on_PatternSearchGroupBox_clicked() { setEmbossApp("fuzzpro"); }
   void on_MarscanGroupBox_clicked() { setEmbossApp("marscan"); }
   void on_PepstatsGroupBox_clicked() { setEmbossApp("pepstats"); }
   void on_CaiGroupBox_clicked() { setEmbossApp("cai"); }
   void on_ChipsGroupBox_clicked() { setEmbossApp("chips"); }
   void on_CuspGroupBox_clicked() { setEmbossApp("cusp"); }
   void on_PscanGroupBox_clicked() { setEmbossApp("pscan"); }
   void on_GeeCeeGroupBox_clicked() { setEmbossApp("geecee"); }
   void on_GarnierGroupBox_clicked() { setEmbossApp("garnier"); }
   void on_InputComboBox_currentIndexChanged(int index);
   void on_InputComboBox2_currentIndexChanged(int index);
   void on_MotifIsInPROSITEFormatCheckBox_stateChanged(int state);
   void on_OutfileAssociatedQualifiersPushButton2_clicked();
   void on_AminoAcidDataFilePushButton_clicked() { selectOpenFile("Open amino acids property file", AminoAcidDataFileLineEdit); }
   void on_MolecularWeightsDataFilePushButton_clicked() { selectOpenFile("Open molecular weight data for amino acids file", MolecularWeightsDataFileLineEdit); }

private:
   virtual void beforeRunningProgram();
   QString qualifierNum;
};

class kantigenic : public kprogramWindow, private Ui::kantigenic
{
    Q_OBJECT
public:
    kantigenic(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class kassembly : public kprogramWindow, private Ui::kassembly
{
    Q_OBJECT
public:
    kassembly(kemboss *parent = nullptr, const QString program = "") : kprogramWindow(parent) { setupUi(this); postWindowCreated(); setEmbossApp(program); }
    void setEmbossApp(const QString &appName);

private slots:
    void on_InfoassemblyGroupBox_clicked(bool checked) { if (checked) runEmbossApp->setEmbossApp("infoassembly"); else runEmbossApp->setEmbossApp("assemblyget"); }
    void on_GcBiasMetricsOutfilePushButton_clicked() { selectSaveFile("Select GC bias metrics outfile", GcBiasMetricsOutfileLineEdit); }
    void on_QualValuesDistOutfilePushButton_clicked() { selectSaveFile("Select outfile for distribution of quality values for the reads", QualValuesDistOutfileLineEdit); }
    void on_RefsequencePushButton_clicked() { selectOpenFile("Open reference sequences for the reads", RefsequenceLineEdit); }
    void on_RefsequenceAssociatedQualifiersPushButton_clicked() { openSAQForm(""); }

private:
   virtual void beforeRunningProgram();
};

class kbacktranambig : public kprogramWindow, private Ui::kbacktranambig
{
    Q_OBJECT
public:
    kbacktranambig(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    virtual void beforeRunningProgram();
};

class kbacktranseq : public kprogramWindow, private Ui::kbacktranseq
{
    Q_OBJECT
public:
    kbacktranseq(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); loadFormats("codon_usage_files", CodonUsageTableComboBox); }

private:
    virtual void beforeRunningProgram();
};

class kbanana : public kprogramWindow, private Ui::kbanana
{
    Q_OBJECT
public:
    kbanana(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save graph as", OutputFileLineEdit2); }
    void on_DataFilePushButton_clicked() { selectOpenFile("Open DNA base timer roll angles data file", DataFileLineEdit); }

private:
    virtual void beforeRunningProgram();
};

class kbtwisted : public kprogramWindow, private Ui::kbtwisted
{
    Q_OBJECT
public:
    kbtwisted(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_AngleDataFilePushButton_clicked() { selectOpenFile("Select DNA base pair twist angle data file", AngleDataFileLineEdit); }
    void on_EnergyDataFilePushButton_clicked() { selectOpenFile("Select DNA base pair stacking energies data file", EnergyDataFileLineEdit); }

private:
    virtual void beforeRunningProgram();
};

class kchaos : public kprogramWindow, private Ui::kchaos
{
    Q_OBJECT
public:
    kchaos(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class kcharge : public kprogramWindow, private Ui::kcharge
{
    Q_OBJECT
public:
   kcharge(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save graph as", OutputFileLineEdit2); }
   void on_AminoAcidDataFilePushButton_clicked() { selectOpenFile("Open amino acids data file", AminoAcidDataFileLineEdit); }

private:
   virtual void beforeRunningProgram();
};

class kchecktrans : public kprogramWindow, private Ui::kchecktrans
{
    Q_OBJECT
public:
    kchecktrans(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save feature file as", OutputFileLineEdit2); }
    void on_SaveOutputFileAsPushButton3_clicked() { selectSaveFile("Save ORF sequences as", OutputFileLineEdit3); }
    void on_OutfeatAssociatedQualifiersPushButton2_clicked() { openOfAQForm("4"); }
    void on_OutseqAssociatedQualifiersPushButton2_clicked() { openOsAQForm("3"); }

private:
    virtual void beforeRunningProgram();
};

class kcompseq : public kprogramWindow, private Ui::kcompseq
{
    Q_OBJECT
public:
    kcompseq(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    virtual void beforeRunningProgram();
};

class kcodcmp : public kprogramWindow, private Ui::kcodcmp
{
    Q_OBJECT
public:
    kcodcmp(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
   virtual void beforeRunningProgram();
};

class kcodcopy : public kprogramWindow, private Ui::kcodcopy
{
    Q_OBJECT
public:
    kcodcopy(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class kcoderet : public kprogramWindow, private Ui::kcoderet
{
   Q_OBJECT
public:
   kcoderet(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_CodingNucleotidesPushButton_clicked() { selectSaveFile("Save coding nucleotide output sequence(s) as", CodingNucleotidesLineEdit); }
   void on_MessengerRNAPushButton_clicked() { selectSaveFile("Save messenger RNA nucleotide output sequence(s) as", MessengerRNALineEdit); }
   void on_TranslatedProteinPushButton_clicked() { selectSaveFile("Save translated coding protein output sequence(s) as", TranslatedProteinLineEdit); }
   void on_NonCodingNucleotidesPushButton_clicked() { selectSaveFile("Save non-coding nucleotide output sequence(s) as", NonCodingNucleotidesLineEdit); }
   void on_OutseqAssociatedQualifiersPushButton2_clicked() { openOsAQForm("3"); }
   void on_OutseqAssociatedQualifiersPushButton3_clicked() { openOsAQForm("4"); }
   void on_OutseqAssociatedQualifiersPushButton4_clicked() { openOsAQForm("5"); }
   void on_OutseqAssociatedQualifiersPushButton5_clicked() { openOsAQForm("6"); }

private:
   virtual void beforeRunningProgram();
};

class kcons : public kprogramWindow, private Ui::kcons
{
    Q_OBJECT
public:
    kcons(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    virtual void beforeRunningProgram();
};

class kconsambig : public kprogramWindow, private Ui::kconsambig
{
    Q_OBJECT
public:
    kconsambig(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class kcpgplot : public kprogramWindow, private Ui::kcpgplot
{
    Q_OBJECT
public:
    kcpgplot(kemboss *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
    void on_SaveFeatureFileAsPushButton_clicked() { selectSaveFile("Save feature file as", FeatureFileLineEdit); }
    void on_SaveGraphAsPushButton_clicked() { selectSaveFile("Save graph as", GraphLineEdit); }
    void on_ProgramComboBox_currentIndexChanged(const QString &text);

private:
    virtual void beforeRunningProgram();
};

class kcpgreport : public kprogramWindow, private Ui::kcpgreport
{
    Q_OBJECT
public:
    kcpgreport(kemboss *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
    void on_SaveFeatureFileAsPushButton_clicked() { selectSaveFile("Save feature file as", FeatureFileLineEdit); }
    void on_ProgramComboBox_currentIndexChanged(const QString &text);

private:
    virtual void beforeRunningProgram();
};

class kdan : public kprogramWindow, private Ui::kdan
{
    Q_OBJECT
public:
    kdan(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    virtual void beforeRunningProgram();
};

class kdensity : public kprogramWindow, private Ui::kdensity
{
    Q_OBJECT
public:
    kdensity(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_OutfileAssociatedQualifiersPushButton2_clicked() { openOAQForm(""); }
   void on_SaveGraphAsPushButton_clicked() { selectSaveFile("Save graph as", GraphLineEdit); }

private:
    virtual void beforeRunningProgram();
};

class kdiffseq : public kprogramWindow, private Ui::kdiffseq
{
    Q_OBJECT
public:
   kdiffseq(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_SequenceAssociatedQualifiersPushButton2_clicked() { openSAQForm("2"); }
   void on_OutfileAssociatedQualifiersPushButton2_clicked() { openOAQForm("3"); }
   void on_WriteFeatureTableAToPushButton_clicked() { selectSaveFile("Write feature table A to", WriteFeatureTableAToLineEdit); }
   void on_WriteFeatureTableBToPushButton_clicked() { selectSaveFile("Write feature table B to", WriteFeatureTableBToLineEdit); }
   void on_OutfeatAssociatedQualifiersPushButton2_clicked() { openOfAQForm("4"); }
   void on_OutfeatAssociatedQualifiersPushButton3_clicked() { openOfAQForm("5"); }

private:
   virtual void beforeRunningProgram();
};

class kpepdigest : public kprogramWindow, private Ui::kdigest
{
    Q_OBJECT
public:
    kpepdigest(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_DataFilePushButton_clicked() { selectOpenFile("Select molecular weight data file",DataFileLineEdit); }

private:
    virtual void beforeRunningProgram();
};

class kdistmat : public kprogramWindow, private Ui::kdistmat
{
    Q_OBJECT
public:
    kdistmat(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    virtual void beforeRunningProgram();
};

class kdotplot : public kprogramWindow, private Ui::kdotplot
{
   Q_OBJECT
public:
   kdotplot(kemboss *parent = nullptr, const int &program = 0);

private slots:
   void on_SequenceAssociatedQualifiersPushButton2_clicked() { openSAQForm("2"); }
   void on_ProgramComboBox_currentIndexChanged(const QString &text);

private:
    virtual void beforeRunningProgram();
};

class kdrawmap : public kprogramWindow, private Ui::kdrawmap
{
    Q_OBJECT
public:
    kdrawmap(kemboss *parent = nullptr, const int &program = 0);

private slots:
    void on_ProgramComboBox_currentIndexChanged(const QString &text);

private:
    virtual void beforeRunningProgram();
};

class kedialign : public kprogramWindow, private Ui::kedialign
{
    Q_OBJECT
public:
    kedialign(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_OutseqAssociatedQualifiersPushButton2_clicked() { openOsAQForm("3"); }
   void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save sequence alignment as", OutputFileLineEdit2); }

private:
   virtual void beforeRunningProgram();
};

class keinverted : public kprogramWindow, private Ui::keinverted
{
    Q_OBJECT
public:
    keinverted(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save sequences of the inverted repeat regions as", OutputFileLineEdit2); }
   void on_OutseqAssociatedQualifiersPushButton2_clicked() { openOsAQForm("3"); }

private:
   virtual void beforeRunningProgram();
};

class kemma : public kprogramWindow, private Ui::kemma
{
    Q_OBJECT
public:
    kemma(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_SaveDendrogramAsPushButton_clicked() { selectSaveFile("Save dendrogram as", DendrogramFileLineEdit); }
    void on_OpenUserPairwiseMatrixPushButton_clicked() { selectOpenFile("Open pairwise alignment matrix file",UserPairwiseMatrixLineEdit); }
    void on_OpenUserMultipleAlignmentMatrixPushButton_clicked() { selectOpenFile("Open multiple alignment matrix file",UserMultipleAlignmentMatrixLineEdit); }
    void on_OpenOldDendrogramPushButton_clicked() { selectOpenFile("Open old dendrogram",OldDendrogramLineEdit); }

private:
    virtual void beforeRunningProgram();
};

class kemowse : public kprogramWindow, private Ui::kemowse
{
    Q_OBJECT
public:
    kemowse(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
   virtual void beforeRunningProgram();
};

class kepestfind : public kprogramWindow, private Ui::kepestfind
{
    Q_OBJECT
public:
    kepestfind(kembossWindow *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save graph as", OutputFileLineEdit2); }
    void on_OpenDataFilePushButton_clicked() { selectOpenFile("Open molecular weights data file",DataFileLineEdit); }

private:
   virtual void beforeRunningProgram();
};

class keprimer3 : public kprogramWindow, private Ui::keprimer3
{
    Q_OBJECT
public:
    keprimer3(kemboss *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
    void on_ProgramComboBox_currentIndexChanged(const QString &text);
    void on_OligoMishybridizationLibraryPushButton_clicked() { selectOpenFile("Select oligo mishybridization library",OligoMishyridizationLibraryLineEdit); }
    void on_MisprimingLibraryPushButton_clicked() { selectOpenFile("Select mispriming library",MisprimingLibraryLineEdit); }

private:
    virtual void beforeRunningProgram();
};

class kequicktandem : public kprogramWindow, private Ui::kequicktandem
{
    Q_OBJECT
public:
    kequicktandem(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save Sanger Centre program quicktandem output file as", OutputFileLineEdit2); }

private:
    virtual void beforeRunningProgram();
};

class kest2genome : public kprogramWindow, private Ui::kest2genome
{
    Q_OBJECT
public:
    kest2genome(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_SequenceAssociatedQualifiersPushButton2_clicked() { openSAQForm("2");}

private:
    virtual void beforeRunningProgram();
};

class ketandem : public kprogramWindow, private Ui::ketandem
{
    Q_OBJECT
public:
    ketandem(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save Sanger Centre program quicktandem output file as", OutputFileLineEdit2); }

private:
    virtual void beforeRunningProgram();
};

class kextractfeat : public kprogramWindow, private Ui::kextractfeat
{
    Q_OBJECT
public:
    kextractfeat(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    virtual void beforeRunningProgram();
};

class kfeatcopy : public kprogramWindow, private Ui::kfeatcopy
{
    Q_OBJECT
public:
    kfeatcopy(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_OutfeatAssociatedQualifiersPushButton2_clicked() { openOfAQForm("2"); }
   void on_FeaturesAssociatedQualifiersPushButton_clicked() { openFAQForm("1"); }
};

class kfeatmerge : public kprogramWindow, private Ui::kfeatmerge
{
    Q_OBJECT
public:
    kfeatmerge(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_OutfeatAssociatedQualifiersPushButton2_clicked() { openOfAQForm("3"); }
   void on_AFeaturesAssociatedQualifiersPushButton_clicked() { openFAQForm("1"); }
   void on_BFeaturesAssociatedQualifiersPushButton_clicked() { openFAQForm("2"); }

private:
    virtual void beforeRunningProgram();
};

class kfeatreport : public kprogramWindow, private Ui::kfeatreport
{
    Q_OBJECT
public:
    kfeatreport(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_OutfileAssociatedQualifiersPushButton2_clicked() { openOAQForm("3"); }
   void on_FeaturesAssociatedQualifiersPushButton2_clicked() { openFAQForm("2"); }

private:
    virtual void beforeRunningProgram();
};

class kfindkm : public kprogramWindow, private Ui::kfindkm
{
    Q_OBJECT
public:
    kfindkm(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save graph as", OutputFileLineEdit2); }

private:
   virtual void beforeRunningProgram();
};

class kfreak : public kprogramWindow, private Ui::kfreak
{
    Q_OBJECT
public:
    kfreak(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save graph as", OutputFileLineEdit2); }

private:
   virtual void beforeRunningProgram();
};

class kgetorf : public kprogramWindow, private Ui::kgetorf
{
    Q_OBJECT
public:
    kgetorf(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    virtual void beforeRunningProgram();
};

class khelixturnhelix : public kprogramWindow, private Ui::khelixturnhelix
{
    Q_OBJECT
public:
    khelixturnhelix(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class khmoment : public kprogramWindow, private Ui::khmoment
{
    Q_OBJECT
public:
    khmoment(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save graph as", OutputFileLineEdit2); }

private:
    virtual void beforeRunningProgram();
};

class kiep : public kprogramWindow, private Ui::kiep
{
    Q_OBJECT
public:
    kiep(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save graph as", OutputFileLineEdit2); }

private:
   virtual void beforeRunningProgram();
};

class kinfo : public kprogramWindow, private Ui::kinfo
{
   Q_OBJECT
public:
   kinfo(kemboss *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
   void on_ProgramComboBox_currentIndexChanged(int index);
   void on_AAPropertiesFilePushButton_clicked() { selectOpenFile(tr("Open amino acid properties data file") ,AAPropertiesFileLineEdit); }
   void on_AAMolWeightPushButton_clicked() { selectOpenFile(tr("Open amino acid molecular weights data file") ,AAMolWeightLineEdit); }

private:
   virtual void beforeRunningProgram();
};

class kinfoalign : public kprogramWindow, private Ui::kinfoalign
{
    Q_OBJECT
public:
    kinfoalign(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class kinfoseq : public kprogramWindow, private Ui::kinfoseq
{
    Q_OBJECT
public:
    kinfoseq(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class kisochore : public kprogramWindow, private Ui::kisochore
{
    Q_OBJECT
public:
    kisochore(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile(tr("Save graph as"), OutputFileLineEdit2); }

private:
    virtual void beforeRunningProgram();
};

class kjaspscan : public kprogramWindow, private Ui::kjaspscan
{
    Q_OBJECT
public:
    kjaspscan(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    virtual void beforeRunningProgram();
};

class klistor : public kprogramWindow, private Ui::klistor
{
    Q_OBJECT
public:
    klistor(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_SequenceAssociatedQualifiersPushButton2_clicked() { openSAQForm("2"); }

private:
   virtual void beforeRunningProgram();
};

class kmakeseq : public kprogramWindow, private Ui::kmakeseq
{
    Q_OBJECT
public:
    kmakeseq(kemboss *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
   void on_OutseqAssociatedQualifiersPushButton2_clicked() { openOsAQForm("1"); }
   void on_DataFilePushButton_clicked() { selectOpenFile("Open codon usage / pepstats file",DataFileLineEdit); }
   void on_ProgramComboBox_currentIndexChanged(const QString &text);

private:
   virtual void beforeRunningProgram();
};

class kmaskfeat : public kprogramWindow, private Ui::kmaskfeat
{
    Q_OBJECT
public:
    kmaskfeat(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class kmegamerger : public kprogramWindow, private Ui::kmegamerger
{
    Q_OBJECT
public:
   kmegamerger(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_SequenceAssociatedQualifiersPushButton2_clicked() { openSAQForm("2"); }
   void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save sequence output as", OutputFileLineEdit2); }
   void on_OutseqAssociatedQualifiersPushButton2_clicked(){ openOsAQForm("3"); }

private:
   virtual void beforeRunningProgram();
};

class kmerger : public kprogramWindow, private Ui::kmerger
{
   Q_OBJECT
public:
   kmerger(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_SequenceAssociatedQualifiersPushButton2_clicked() { openSAQForm("2"); }
   void on_OutseqAssociatedQualifiersPushButton2_clicked() { openOsAQForm("4"); }
   void on_SaveMergedSequenceAsPushButton_clicked() { selectSaveFile("Save merged sequence as", MergedSequenceLineEdit); }

private:
    virtual void beforeRunningProgram();
};

class kmodifyseq : public kprogramWindow, private Ui::kmodifyseq
{
    Q_OBJECT
public:
   kmodifyseq(kemboss *parent = nullptr, const QString program = "") : kprogramWindow(parent) { setupUi(this); postWindowCreated(); setEmbossApp(program); }
   void setEmbossApp(const QString &appName);

private slots:
   void on_DeleteRegionGroupBox_clicked() { setEmbossApp("cutseq"); }
   void on_SplitterGroupBox_clicked() { setEmbossApp("splitter"); }
   void on_RemoveGapCharactersGroupBox_clicked() { setEmbossApp("degapseq"); }
   void on_PasteseqGroupBox_clicked() { setEmbossApp("pasteseq"); }
   void on_ExcludeSequencesGroupBox_clicked() { setEmbossApp("notseq"); }
   void on_ExtractseqGroupBox_clicked() { setEmbossApp("extractseq"); }
   void on_ExtractalignGroupBox_clicked() { setEmbossApp("extractalign"); }
   void on_MaskRegionGroupBox_clicked() { setEmbossApp("maskseq"); }
   void on_ReverseComplementGroupBox_clicked() { setEmbossApp("revseq"); }
   void on_ShuffleSequenceGroupBox_clicked() { setEmbossApp("shuffleseq"); }
   void on_DescseqGroupBox_clicked() { setEmbossApp("descseq"); }
   void on_BiosedGroupBox_clicked() { setEmbossApp("biosed"); }
   void on_MaskAmbiguityCaractersNGroupBox_clicked() { setEmbossApp("maskambignuc"); }
   void on_MaskAmbiguityCaractersPGroupBox_clicked() { setEmbossApp("maskambigprot"); }
   void on_SortBySizeGroupBox_clicked() { setEmbossApp("sizeseq"); }

   void on_SequenceToInsertPushButton_clicked() { selectOpenFile("Select sequence to insert",SequenceToInsertLineEdit); }
   void on_WriteExcludedSequencesToPushButton_clicked() { selectSaveFile("Save excluded sequences as", WriteExcludedSequencesToLineEdit); }
   void on_SequenceAssociatedQualifiersPushButton2_clicked() { openSAQForm("2"); }
   void outseqAssociatedQualifiersPushButton2_clicked() { openOsAQForm("3"); }
   void on_OutseqAssociatedQualifiersPushButton3_clicked() { openOsAQForm(""); }

private:
    virtual void beforeRunningProgram();
};

class kmsbar : public kprogramWindow, private Ui::kmsbar
{
    Q_OBJECT
public:
    kmsbar(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_DoNotMatchPushButton_clicked() { selectOpenFile("Open sequence set",DoNotMatchLineEdit); }
    void on_SequenceAssociatedQualifiersPushButton2_clicked() { openSAQForm(""); }

private:
    virtual void beforeRunningProgram();
};

class kmwfilter : public kprogramWindow, private Ui::kmwfilter
{
    Q_OBJECT
public:
    kmwfilter(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_DataFilePushButton_clicked() { selectOpenFile("Open molecular weight standards data file",DataFileLineEdit); }

private:
    virtual void beforeRunningProgram();
};

class kmwcontam : public kprogramWindow, private Ui::kmwcontam
{
    Q_OBJECT
public:
    kmwcontam(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class knewseq : public kprogramWindow, private Ui::knewseq
{
    Q_OBJECT
public:
    knewseq(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_OutseqAssociatedQualifiersPushButton2_clicked() { openOsAQForm("5"); }

private:
   virtual void beforeRunningProgram();
};

class kno : public kprogramWindow, private Ui::kno
{
    Q_OBJECT
public:
    kno(kemboss *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
   void on_ProgramComboBox_currentIndexChanged(const QString &text);
};

class koctanol : public kprogramWindow, private Ui::koctanol
{
    Q_OBJECT
public:
    koctanol(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_DataFilePushButton_clicked() { selectOpenFile("Open White-Wimley data file",DataFileLineEdit); }

private:
   virtual void beforeRunningProgram();
};

class koddcomp : public kprogramWindow, private Ui::koddcomp
{
    Q_OBJECT
public:
    koddcomp(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_DataFilePushButton_clicked() { selectOpenFile("Open amino acid composition data file",DataFileLineEdit); }

private:
   virtual void beforeRunningProgram();
};

class kpalindrome : public kprogramWindow, private Ui::kpalindrome
{
    Q_OBJECT
public:
    kpalindrome(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class kpatmatmotifs : public kprogramWindow, private Ui::kpatmatmotifs
{
    Q_OBJECT
public:
    kpatmatmotifs(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class kpepcoil : public kprogramWindow, private Ui::kpepcoil
{
    Q_OBJECT
public:
    kpepcoil(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class kpepdisplay : public kprogramWindow, private Ui::kpepdisplay
{
    Q_OBJECT
public:
    kpepdisplay(kemboss *parent = nullptr, const int &program = 0);

private slots:
    void on_ProgramComboBox_currentIndexChanged(const QString &text);
};

class kpepinfo : public kprogramWindow, private Ui::kpepinfo
{
    Q_OBJECT
public:
    kpepinfo(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save graph as", OutputFileLineEdit2); }
    void on_ChemicalClassesPushButton_clicked() { selectOpenFile("Open amino acids chemical classes data file",ChemicalClassesLineEdit); }
    void on_HydropathyDataPushButton_clicked() { selectOpenFile("Open amino acids hydropathy values data file",HydropathyDataLineEdit); }

private:
    virtual void beforeRunningProgram();
};

class kpepwindow : public kprogramWindow, private Ui::kpepwindow
{
    Q_OBJECT
public:
    kpepwindow(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_DataFilePushButton_clicked() { selectOpenFile("Open AAINDEX entry data file",DataFileLineEdit); }
    void on_SuperimposePlotsCheckBox_stateChanged(int state);

private:
   virtual void beforeRunningProgram();
};

class kplotcon : public kprogramWindow, private Ui::kplotcon
{
    Q_OBJECT
public:
    kplotcon(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class kplotorf : public kprogramWindow, private Ui::kplotorf
{
    Q_OBJECT
public:
    kplotorf(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class kpolydot : public kprogramWindow, private Ui::kpolydot
{
    Q_OBJECT
public:
    kpolydot(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_SaveFeaturesFileAsPushButton_clicked() { selectSaveFile("Save features file as", FeaturesFileLineEdit); }

private:
    virtual void beforeRunningProgram();
};

class kprettyplot : public kprogramWindow, private Ui::kprettyplot
{
    Q_OBJECT
public:
    kprettyplot(kemboss *parent = nullptr);

private:
    virtual void beforeRunningProgram();
};

class kprettyseq : public kprogramWindow, private Ui::kprettyseq
{
    Q_OBJECT
public:
    kprettyseq(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    virtual void beforeRunningProgram();
};

class kprimersearch : public kprogramWindow, private Ui::kprimersearch
{
    Q_OBJECT
public:
    kprimersearch(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    virtual void beforeRunningProgram();
};

class kprofit : public kprogramWindow, private Ui::kprofit
{
   Q_OBJECT
public:
   kprofit(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_DataFilePushButton_clicked() { selectOpenFile("Open profile or weight matrix file",DataFileLineEdit); }
   void on_SequenceAssociatedQualifiersPushButton2_clicked() { openSAQForm("2"); }

private:
    virtual void beforeRunningProgram();
};

class kprophecy : public kprogramWindow, private Ui::kprophecy
{
    Q_OBJECT
public:
    kprophecy(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    virtual void beforeRunningProgram();
};

class kprophet : public kprogramWindow, private Ui::kprophet
{
    Q_OBJECT
public:
    kprophet(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_DataFilePushButton_clicked() { selectOpenFile("Open profile or weight matrix file",DataFileLineEdit); }

private:
    virtual void beforeRunningProgram();
};

class kpsiphi : public kprogramWindow, private Ui::kpsiphi
{
    Q_OBJECT
public:
    kpsiphi(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class kredata : public kprogramWindow, private Ui::kredata
{
    Q_OBJECT
public:
    kredata(kemboss *parent = nullptr);
};

class kremap : public kprogramWindow, private Ui::kremap
{
    Q_OBJECT
public:
    kremap(kemboss *parent = nullptr);

private slots:
    void on_AddEnzymePushButton_clicked();
    void on_RemoveEnzymePushButton_clicked();
    void on_SaveEnzymeListAsPushButton_clicked();
    void on_OpenEnzymeListPushButton_clicked() { selectOpenFile("Use enzyme list" ,UseListLineEdit); UseListRadioButton->setChecked(true); }
    void on_MethylationDataFilePushButton_clicked() { selectOpenFile("Open methylation data file",MethylationDataFileLineEdit); }

private:
    virtual void beforeRunningProgram();
};

class kremutate : public kprogramWindow, private Ui::kremutate
{
    Q_OBJECT
public:
    kremutate(kemboss *parent = nullptr, const int &program = 0);

private slots:
    void on_ProgramComboBox_currentIndexChanged(const QString &text);
    void on_AddEnzymePushButton_clicked();
    void on_RemoveEnzymePushButton_clicked();
    void on_SaveEnzymeListAsPushButton_clicked();
    void on_OpenEnzymeListPushButton_clicked() { selectOpenFile("Use enzyme list" ,UseListLineEdit); UseListRadioButton->setChecked(true); }

private:
   virtual void beforeRunningProgram();
};

class krestover : public kprogramWindow, private Ui::krestover
{
    Q_OBJECT
public:
    krestover(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_AlternativeREDataFilePushButton_clicked() { selectOpenFile("Open restriction enzyme data file",AlternativeREDataFileLineEdit); }
    void on_MethylationDataFilePushButton_clicked() { selectOpenFile("Open methylation data file",MethylationDataFileLineEdit); }

private:
    virtual void beforeRunningProgram();
};

class krestrict : public kprogramWindow, private Ui::krestrict
{
    Q_OBJECT
public:
    krestrict(kemboss *parent = nullptr);

private slots:
    void on_AddEnzymePushButton_clicked();
    void on_RemoveEnzymePushButton_clicked();
    void on_SaveEnzymeListAsPushButton_clicked();
    void on_OpenEnzymeListPushButton_clicked() { selectOpenFile("Use enzyme list" ,UseListLineEdit); UseListRadioButton->setChecked(true); }
    void on_AlternativeREDataFilePushButton_clicked() { selectOpenFile("Open restriction enzyme data file",AlternativeREDataFileLineEdit); }
    void on_MethylationDataFilePushButton_clicked() { selectOpenFile("Open methylation data file",MethylationDataFileLineEdit); }

private:
    virtual void beforeRunningProgram();
};

class kseq : public kprogramWindow, private Ui::kseq
{
    Q_OBJECT
public:
    kseq(kemboss *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
    void on_ProgramComboBox_currentIndexChanged(const QString &text);
};

class kshowalign : public kprogramWindow, private Ui::kshowalign
{
    Q_OBJECT
public:
    kshowalign(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    virtual void beforeRunningProgram();
};

class kshowfeat : public kprogramWindow, private Ui::kshowfeat
{
    Q_OBJECT
public:
    kshowfeat(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    virtual void beforeRunningProgram();
};

class kshoworf : public kprogramWindow, private Ui::kshoworf
{
    Q_OBJECT
public:
    kshoworf(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    virtual void beforeRunningProgram();
};

class kshowseq : public kprogramWindow, private Ui::kshowseq
{
    Q_OBJECT
public:
    kshowseq(kemboss *parent = nullptr);

private slots:
    void on_AddEnzymePushButton_clicked();
    void on_RemoveEnzymePushButton_clicked();
    void on_SaveEnzymeListAsPushButton_clicked();
    void on_OpenEnzymeListPushButton_clicked() { selectOpenFile("Use enzyme list" ,UseListLineEdit); UseListRadioButton->setChecked(true); }
    void on_MethylationDataFilePushButton_clicked() { selectOpenFile("Open methylation data file",MethylationDataFileLineEdit); }

private:
    virtual void beforeRunningProgram();
};

class kshowpep : public kprogramWindow, private Ui::kshowpep
{
    Q_OBJECT
public:
    kshowpep(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    virtual void beforeRunningProgram();
};

class ksigcleave : public kprogramWindow, private Ui::ksigcleave
{
    Q_OBJECT
public:
    ksigcleave(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class ksirna : public kprogramWindow, private Ui::ksirna
{
    Q_OBJECT
public:
   ksirna(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_OutseqAssociatedQualifiersPushButton2_clicked() { openOsAQForm("3"); }
   void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save output sequences as", OutputFileLineEdit2); }

private:
   virtual void beforeRunningProgram();
};

class ksixpack : public kprogramWindow, private Ui::ksixpack
{
    Q_OBJECT
public:
   ksixpack(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save translated sequences as", OutputFileLineEdit2); }

private:
   virtual void beforeRunningProgram();
};

class kskipredundant : public kprogramWindow, private Ui::kskipredundant
{
    Q_OBJECT
public:
   kskipredundant(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_ModeComboBox_currentIndexChanged(int index);
   void on_OutseqAssociatedQualifiersPushButton2_clicked() { openOsAQForm("3"); }
   void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save redundant sequences as", OutputFileLineEdit2); }

private:
   virtual void beforeRunningProgram();
};

class kstssearch : public kprogramWindow, private Ui::kstssearch
{
    Q_OBJECT
public:
    kstssearch(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
   virtual void beforeRunningProgram();
};

class ksyco : public kprogramWindow, private Ui::ksyco
{
    Q_OBJECT
public:
    ksyco(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save graph as", OutputFileLineEdit2); }

private:
    virtual void beforeRunningProgram();
};

class ktcode : public kprogramWindow, private Ui::ktcode
{
    Q_OBJECT
public:
    ktcode(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_OutfileAssociatedQualifiersPushButton2_clicked() { openOAQForm(""); }
   void on_SaveGraphAsPushButton_clicked() { selectSaveFile("Save graph as", GraphOutputFileLineEdit); }
   void on_DataFilePushButton_clicked() { selectOpenFile("Open coding probabilities data file" ,DataFileLineEdit); }

private:
    virtual void beforeRunningProgram();
};

class ktextsearch : public kprogramWindow, private Ui::ktextsearch
{
    Q_OBJECT
public:
    ktextsearch(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class ktfscan : public kprogramWindow, private Ui::ktfscan
{
    Q_OBJECT
public:
    ktfscan(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_CustomDataFilePushButton_clicked() { selectOpenFile("Open TRANSFAC database data file",CustomDataFileLineEdit); }

private:
   virtual void beforeRunningProgram();
};

class ktmap : public kprogramWindow, private Ui::ktmap
{
    Q_OBJECT
public:
    ktmap(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save graph as", OutputFileLineEdit2); }

private:
    virtual void beforeRunningProgram();
};

class ktranalign : public kprogramWindow, private Ui::ktranalign
{
   Q_OBJECT
public:
   ktranalign(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_SequenceAssociatedQualifiersPushButton2_clicked() { openSAQForm("2"); }
   void on_OutseqAssociatedQualifiersPushButton2_clicked() { openOsAQForm("3"); }

private:
   virtual void beforeRunningProgram();
};

class ktranseq : public kprogramWindow, private Ui::ktranseq
{
    Q_OBJECT
public:
    ktranseq(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    virtual void beforeRunningProgram();
};

class ktrimest : public kprogramWindow, private Ui::ktrimest
{
    Q_OBJECT
public:
    ktrimest(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class ktrimseq : public kprogramWindow, private Ui::ktrimseq
{
    Q_OBJECT
public:
    ktrimseq(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class ktwofeat : public kprogramWindow, private Ui::ktwofeat
{
    Q_OBJECT
public:
    ktwofeat(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private:
    virtual void beforeRunningProgram();
};

class kunion : public kprogramWindow, private Ui::kunion
{
    Q_OBJECT
public:
    kunion(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_SequenceOverlapsOutputFilePushButton_clicked() { selectSaveFile("Save sequence overlaps as", SequenceOverlapsOutputFileLineEdit); }

private:
    virtual void beforeRunningProgram();
};

class kvectorstrip : public kprogramWindow, private Ui::kvectorstrip
{
    Q_OBJECT
public:
    kvectorstrip(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
    void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save stripped sequences as", OutputFileLineEdit2); }
    void on_OutseqAssociatedQualifiersPushButton2_clicked() { openOsAQForm("4"); }
    void on_SelectVectorFilePushButton_clicked() { selectOpenFile("Select cloning vector definition file",SelectVectorFileLineEdit); }

private:
    virtual void beforeRunningProgram();
};

class kwhichdb : public kprogramWindow, private Ui::kwhichdb
{
    Q_OBJECT
public:
    kwhichdb(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

class kwobble : public kprogramWindow, private Ui::kwobble
{
    Q_OBJECT
public:
    kwobble(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save graph as", OutputFileLineEdit2); }

private:
   virtual void beforeRunningProgram();
};

class kwordfinder : public kprogramWindow, private Ui::kwordfinder
{
    Q_OBJECT
public:
    kwordfinder(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_SequenceAssociatedQualifiersPushButton2_clicked() { openSAQForm("2"); }
   void on_ErrorfilePushButton_clicked() { selectSaveFile("Save error file as",ErrorfileLineEdit); }

private:
   virtual void beforeRunningProgram();
};

class kwordmatch : public kprogramWindow, private Ui::kwordmatch
{
    Q_OBJECT
public:
    kwordmatch(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }

private slots:
   void on_SequenceAssociatedQualifiersPushButton2_clicked() { openSAQForm("2"); }
   void on_OutfeatAssociatedQualifiersPushButton2_clicked() { openOfAQForm("4"); }
   void on_OutfeatAssociatedQualifiersPushButton3_clicked() { openOfAQForm("5"); }
   void on_SaveOutputFileAsPushButton2_clicked() { selectSaveFile("Save feature table A as", OutputFileLineEdit2); }
   void on_SaveOutputFileAsPushButton3_clicked() { selectSaveFile("Save feature table B as", OutputFileLineEdit3); }
   void on_LogfileSaveAsPushButton_clicked() { selectSaveFile("Save logfile as", LogfileLineEdit); }

private:
   virtual void beforeRunningProgram();
};

class kedam : public kprogramWindow, private Ui::kedam
{
    Q_OBJECT
public:
    kedam(kemboss *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
    void on_ProgramComboBox_currentIndexChanged(const QString &text);

private:
   virtual void beforeRunningProgram();
};

class kfinddatabase : public kprogramWindow, private Ui::kfinddatabase
{
    Q_OBJECT
public:
    kfinddatabase(kemboss *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
    void on_ProgramComboBox_currentIndexChanged(const QString &text);
};

class konto : public kprogramWindow, private Ui::konto
{
    Q_OBJECT
public:
    konto(kemboss *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
    void on_ProgramComboBox_currentIndexChanged(const QString &text);
};

class ktax : public kprogramWindow, private Ui::ktax
{
    Q_OBJECT
public:
    ktax(kemboss *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
    void on_ProgramComboBox_currentIndexChanged(const QString &text);

private:
   virtual void beforeRunningProgram();
};

class kgo : public kprogramWindow, private Ui::kgo
{
    Q_OBJECT
public:
    kgo(kemboss *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
    void on_ProgramComboBox_currentIndexChanged(const QString &text);

private:
   virtual void beforeRunningProgram();
};

class kdr : public kprogramWindow, private Ui::kdr
{
    Q_OBJECT
public:
    kdr(kemboss *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
    void on_ProgramComboBox_currentIndexChanged(const QString &text) { runEmbossApp->setEmbossApp(text); }
};

class kget : public kprogramWindow, private Ui::kget
{
    Q_OBJECT
public:
    kget(kemboss *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
    void on_ProgramComboBox_currentIndexChanged(const QString &text);
};

class kseqxref : public kprogramWindow, private Ui::kseqxref
{
    Q_OBJECT
public:
    kseqxref(kemboss *parent = nullptr, const int &program = 0) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); kpwProgramComboBox->setCurrentIndex(program); }

private slots:
    void on_ProgramComboBox_currentIndexChanged(const QString &text) { runEmbossApp->setEmbossApp(text); }
};

class kfeattext : public kprogramWindow, private Ui::kfeattext
{
    Q_OBJECT
public:
    kfeattext(kemboss *parent = nullptr) : kprogramWindow(parent) { setupUi(this); postWindowCreated(); }
};

#endif
