/***************************************************************************
 *                                                                         *
 *   kemboss - Graphical user interface for EMBOSS                         *
 *                                                                         *
 *   Copyright (C) 2007-2019 Tobias Schwarz (mail@tobias-schwarz.net)      *
 *                                                                         *
 *   Based on the EMBOSS.kaptn scripts by Thomas Siegmund                  *
 *                                                                         *
 *   This program is free software; you can redistribute and/or modify     *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version, and provided that the above       *
 *   copyright and permission notice is included with all distributed      *
 *   copies of this or derived software.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 **************************************************************************/

#include <QMessageBox>
#include "main.h"
#include "runEmbossApp.h"
#include "programWindowClass.h"

krunEmbossApp::krunEmbossApp(QWidget *parent, kembossSettings *fksettings) : QObject(parent)
{
   parentWindow = parent;
   ksettings = fksettings;
   programProgress = nullptr;
   cShowProgressWindow = true;
}

bool krunEmbossApp::runApp()
{
   // Create program progress window
   if (programProgress == nullptr) {
      programProgress = new programProgressForm(ksettings);
      connect(programProgress->CancelButton, SIGNAL(clicked()), this, SLOT(killProcess()));
   }
   programProgress->ProgramOutputTextEdit->document()->clear();
   programProgress->move(parentWindow->x()+100,parentWindow->y()+150);
   if (cShowProgressWindow) programProgress->show();

   // Display command line options for EMBOSS application in program progress window
   programProgress->ProgramOutputTextEdit->append("Running "+embossApp());
   programProgress->ProgramOutputTextEdit->append(programConfiguration.join("\n"));

   runTime.start(); // Timer to measure program execution time

   return true;

   // In the derived classes krunEmbossAppLocal and krunEmbossAppOnServer the EMBOSS application is executed following these basic preparations
}

void krunEmbossApp::updateProgramProgressForm()
{
    if (!cShowProgressWindow) return;

    if (!programOutput().isEmpty())
        programProgress->ProgramOutputTextEdit->append(programOutput());

    QString timeElapsed;
    timeElapsed.setNum(runTime.elapsed());
    programProgress->RuntimeLabel->setText("Runtime: "+timeElapsed+" ms");
}

void krunEmbossApp::processFinished(int exitCode)
{
   QString timeElapsed;
   timeElapsed.setNum(runTime.elapsed());
   programProgress->RuntimeLabel->setText("Runtime: "+timeElapsed+" ms");
   programProgress->CancelButton->setText(tr("Close"));
   disconnect(programProgress->CancelButton, SIGNAL(clicked()), this, SLOT(killProcess()));
   connect(programProgress->CancelButton, SIGNAL(clicked()), programProgress, SLOT(close()));
   if (exitCode == 0) {
   // On success do
       if (ksettings->autoCloseProgressWindow() || !cShowProgressWindow) {
           programProgress->close();
       } else
           programProgress->ProgramOutputTextEdit->append(tr("Finished successfully"));
   } else {
   // If an error occurred
       if (!programProgress->isVisible()) programProgress->show();
       programProgress->activateWindow();
   }
   emit applicationExecuted(exitCode);
}

void krunEmbossApp::killProcess()
{

}
