/***************************************************************************
 *                                                                         *
 *   kemboss - Graphical user interface for EMBOSS                         *
 *                                                                         *
 *   Copyright (C) 2007-2019 Tobias Schwarz (mail@tobias-schwarz.net)      *
 *                                                                         *
 *   Based on the EMBOSS.kaptn scripts by Thomas Siegmund                  *
 *                                                                         *
 *   This program is free software; you can redistribute and/or modify     *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version, and provided that the above       *
 *   copyright and permission notice is included with all distributed      *
 *   copies of this or derived software.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 **************************************************************************/

#include "shared.h"

#include <QFile>
#include <QCryptographicHash>
#include <QTextStream>

QString kemboss::serverStatusString(const quint8 status)
{
    switch (status) {
    case 1:
        return "Ready";
    case 2:
        return "Server is starting up. Please try again soon";
    case 3:
        return "Server is shutting down. Please try again later";
    case 4:
        return "The server has reached its maximum number of parallel EMBOSS program executions. Please try again later";
    case 5:
        return "An unknown error occured";
    }
    return "";
}

QByteArray kemboss::getFileMD5Sum(const QString &filename)
{
    QCryptographicHash crypto(QCryptographicHash::Md5);
    QFile file(filename);
    if (!file.open(QIODevice::ReadOnly)) {
        QTextStream qstdout(stdout);
        qstdout << "Error in determining MD5sum. Could not open file." << endl;
        return "";
    }
    while(!file.atEnd()){
        crypto.addData(file.read(8192));
    }
    file.close();
    return (crypto.result());
}
